@@ -19,8 +19,8 @@ DATABASES = {
 ROOT_URLCONF = 'rapid_prototyping.tests.urls'
 
 STATIC_URL = '/static/'
-STATIC_ROOT = os.path.join(APP_ROOT, '../static')
-MEDIA_ROOT = os.path.join(APP_ROOT, '../media')
+STATIC_ROOT = os.path.join(APP_ROOT, '../app_static')
+MEDIA_ROOT = os.path.join(APP_ROOT, '../app_media')
 STATICFILES_DIRS = (
     os.path.join(APP_ROOT, 'static'),
 )
@@ -59,3 +59,6 @@ INSTALLED_APPS = EXTERNAL_APPS + INTERNAL_APPS
 COVERAGE_MODULE_EXCLUDES += EXTERNAL_APPS
 
 SECRET_KEY = 'foobar'
+
+RAPID_PROTOTYPING_HOURLY_RATE = 70
+RAPID_PROTOTYPING_SPRINTS_MODULE = 'rapid_prototyping.tests.test_app.context.sprints.sprints'  # NOQA
